@@ -1,5 +1,5 @@
 setOldClass("scalar")
-setMethod("asJSON", "scalar", function(x, ...) {
+setMethod("asJSON", "scalar", function(x, collapse, ...) {
   # TODO: There must be a way to do this with NextMethod()
   if (length(class(x)) > 1) {
     class(x) <- class(x)[-1]
